@@ -108,7 +108,7 @@ void Gripper::startGrip(DockingCont* pCont, DockingManager* pDockMgr)
 	_hSelf = ::CreateWindowEx(
 					0,
 					MDLG_CLASS_NAME,
-					TEXT(""), 0,
+					L"", 0,
 					CW_USEDEFAULT, CW_USEDEFAULT,
 					CW_USEDEFAULT, CW_USEDEFAULT,
 					NULL,
@@ -221,9 +221,9 @@ void Gripper::create()
     if (!hookMouse)
     {
         DWORD dwError = ::GetLastError();
-        TCHAR  str[128];
-        ::wsprintf(str, TEXT("GetLastError() returned %lu"), dwError);
-        ::MessageBox(NULL, str, TEXT("SetWindowsHookEx(MOUSE) failed on Gripper::create()"), MB_OK | MB_ICONERROR);
+        wchar_t  str[128];
+        ::wsprintf(str, L"GetLastError() returned %lu", dwError);
+        ::MessageBox(NULL, str, L"SetWindowsHookEx(MOUSE) failed on Gripper::create()", MB_OK | MB_ICONERROR);
     }
 
 	if (ver != WV_UNKNOWN && ver < WV_VISTA)
@@ -232,9 +232,9 @@ void Gripper::create()
 		if (!hookKeyboard)
 		{
 			DWORD dwError = ::GetLastError();
-			TCHAR  str[128];
-			::wsprintf(str, TEXT("GetLastError() returned %lu"), dwError);
-			::MessageBox(NULL, str, TEXT("SetWindowsHookEx(KEYBOARD) failed on Gripper::create()"), MB_OK | MB_ICONERROR);
+			wchar_t  str[128];
+			::wsprintf(str, L"GetLastError() returned %lu", dwError);
+			::MessageBox(NULL, str, L"SetWindowsHookEx(KEYBOARD) failed on Gripper::create()", MB_OK | MB_ICONERROR);
 		}
 	}
 //  Removed regarding W9x systems
@@ -473,8 +473,8 @@ void Gripper::doTabReordering(POINT pt)
 
 #if 0
 	extern HWND g_hMainWnd;
-	TCHAR str[128];
-	wsprintf(str, TEXT("Size: %i"), vCont.size());
+	wchar_t str[128];
+	wsprintf(str, L"Size: %i", vCont.size());
 	::SetWindowText(g_hMainWnd, str);
 #endif
 
@@ -835,7 +835,7 @@ void Gripper::initTabInformation()
 	::SendMessage(_hTabSource, TCM_GETITEMRECT, _iItem, reinterpret_cast<LPARAM>(&_rcItem));
 
 	/* store item data */
-	static TCHAR	szText[64];
+	static wchar_t	szText[64];
 	_tcItem.mask		= TCIF_PARAM | TCIF_TEXT;
 	_tcItem.pszText		= szText;
 	_tcItem.cchTextMax	= 64;
