@@ -40,7 +40,7 @@
 	#define	IDC_CHECK_ENABLETABCLOSE (IDD_PREFERENCE_SUB_GENRAL + 12)
 	#define	IDC_CHECK_DBCLICK2CLOSE (IDD_PREFERENCE_SUB_GENRAL + 13)
 	#define	IDC_CHECK_ENABLEDOCSWITCHER (IDD_PREFERENCE_SUB_GENRAL + 14)
-	//#define	IDC_CHECK_MAINTAININDENT (IDD_PREFERENCE_SUB_GENRAL + 15)
+	#define	IDC_CHECK_ENABLETABPIN (IDD_PREFERENCE_SUB_GENRAL + 15)
 	#define	IDC_CHECK_KEEPINSAMEDIR (IDD_PREFERENCE_SUB_GENRAL + 16)
 	#define	IDC_CHECK_STYLEMRU (IDD_PREFERENCE_SUB_GENRAL + 17)
 	#define	IDC_CHECK_TAB_HIDE (IDD_PREFERENCE_SUB_GENRAL + 18)
