@@ -22,11 +22,13 @@
 #include "FindReplaceDlg_rc.h"
 #include "NppDarkMode.h"
 
+using namespace std;
+
 constexpr DWORD WS_TOOLBARSTYLE = WS_CHILD | WS_VISIBLE | WS_CLIPCHILDREN | WS_CLIPSIBLINGS | TBSTYLE_TOOLTIPS | TBSTYLE_FLAT | CCS_TOP | CCS_NOPARENTALIGN | CCS_NORESIZE | CCS_NODIVIDER;
 
 struct ToolbarIconIdUnit
 {
-	generic_string _id;
+	wstring _id;
 	bool hasDisabledIcon = false;
 };
 
@@ -67,31 +69,31 @@ ToolbarIconIdUnit toolbarIconIDs[] = {
 
 void ToolBar::initTheme(TiXmlDocument *toolIconsDocRoot)
 {
-    _toolIcons =  toolIconsDocRoot->FirstChild(TEXT("NotepadPlus"));
+    _toolIcons =  toolIconsDocRoot->FirstChild(L"NotepadPlus");
 	if (_toolIcons)
 	{
-		_toolIcons = _toolIcons->FirstChild(TEXT("ToolBarIcons"));
+		_toolIcons = _toolIcons->FirstChild(L"ToolBarIcons");
 		if (_toolIcons)
 		{
-			generic_string iconFolderDir = NppParameters::getInstance().getUserPath();
-			generic_string toolbarIconsRootFolderName = TEXT("toolbarIcons");
+			wstring iconFolderDir = NppParameters::getInstance().getUserPath();
+			wstring toolbarIconsRootFolderName = L"toolbarIcons";
 			pathAppend(iconFolderDir, toolbarIconsRootFolderName);
-			generic_string folderName = (_toolIcons->ToElement())->Attribute(TEXT("icoFolderName"));
+			wstring folderName = (_toolIcons->ToElement())->Attribute(L"icoFolderName");
 			if (folderName.empty())
-				folderName = TEXT("default");
+				folderName = L"default";
 
 			pathAppend(iconFolderDir, folderName);
 
 			size_t i = 0;
-			generic_string disabled_suffix = L"_disabled";
-			generic_string ext = L".ico";
-			for (ToolbarIconIdUnit icoUnit : toolbarIconIDs)
+			wstring disabled_suffix = L"_disabled";
+			wstring ext = L".ico";
+			for (const ToolbarIconIdUnit& icoUnit : toolbarIconIDs)
 			{
-				generic_string locator = iconFolderDir;
+				wstring locator = iconFolderDir;
 				locator += L"\\";
 				locator += icoUnit._id;
 				locator += ext;
-				if (::PathFileExists(locator.c_str()))
+				if (doesFileExist(locator.c_str()))
 				{
 					_customIconVect.push_back(iconLocator(HLIST_DEFAULT, i, locator));
 					_customIconVect.push_back(iconLocator(HLIST_DEFAULT2, i, locator));
@@ -101,12 +103,12 @@ void ToolBar::initTheme(TiXmlDocument *toolIconsDocRoot)
 
 				if (icoUnit.hasDisabledIcon)
 				{
-					generic_string locator_dis = iconFolderDir;
+					wstring locator_dis = iconFolderDir;
 					locator_dis += L"\\";
 					locator_dis += icoUnit._id;
 					locator_dis += disabled_suffix;
 					locator_dis += ext;
-					if (::PathFileExists(locator_dis.c_str()))
+					if (doesFileExist(locator_dis.c_str()))
 					{
 						_customIconVect.push_back(iconLocator(HLIST_DISABLE, i, locator_dis));
 						_customIconVect.push_back(iconLocator(HLIST_DISABLE2, i, locator_dis));
@@ -317,7 +319,7 @@ void ToolBar::reset(bool create)
 		_hSelf = ::CreateWindowEx(
 			WS_EX_PALETTEWINDOW,
 			TOOLBARCLASSNAME,
-			TEXT(""),
+			L"",
 			WS_TOOLBARSTYLE | dwExtraStyle,
 			0, 0,
 			0, 0,
@@ -497,7 +499,7 @@ void ToolBar::doPopop(POINT chevPoint)
 	if (start < _nbCurrentButtons)
 	{	//some buttons are hidden
 		HMENU menu = ::CreatePopupMenu();
-		generic_string text;
+		wstring text;
 		while (start < _nbCurrentButtons)
 		{
 			int cmd = _pTBB[start].idCommand;
@@ -509,7 +511,7 @@ void ToolBar::doPopop(POINT chevPoint)
 				else
 					AppendMenu(menu, MF_DISABLED|MF_GRAYED, cmd, text.c_str());
 			} else
-				AppendMenu(menu, MF_SEPARATOR, 0, TEXT(""));
+				AppendMenu(menu, MF_SEPARATOR, 0, L"");
 			
 			++start;
 		}
