@@ -274,33 +274,33 @@
 
 #define IDM_VIEW    (IDM + 4000)                
     //#define    IDM_VIEW_TOOLBAR_HIDE            (IDM_VIEW + 1)
-    #define    IDM_VIEW_TOOLBAR_REDUCE            (IDM_VIEW + 2)    
-    #define    IDM_VIEW_TOOLBAR_ENLARGE           (IDM_VIEW + 3)
-    #define    IDM_VIEW_TOOLBAR_STANDARD          (IDM_VIEW + 4)
-    #define    IDM_VIEW_REDUCETABBAR              (IDM_VIEW + 5)
-    #define    IDM_VIEW_LOCKTABBAR                (IDM_VIEW + 6) 
-    #define    IDM_VIEW_DRAWTABBAR_TOPBAR         (IDM_VIEW + 7)
-    #define    IDM_VIEW_DRAWTABBAR_INACIVETAB     (IDM_VIEW + 8) 
+    //#define    IDM_VIEW_TOOLBAR_REDUCE            (IDM_VIEW + 2)    
+    //#define    IDM_VIEW_TOOLBAR_ENLARGE           (IDM_VIEW + 3)
+    //#define    IDM_VIEW_TOOLBAR_STANDARD          (IDM_VIEW + 4)
+    //#define    IDM_VIEW_REDUCETABBAR              (IDM_VIEW + 5)
+    //#define    IDM_VIEW_LOCKTABBAR                (IDM_VIEW + 6) 
+    //#define    IDM_VIEW_DRAWTABBAR_TOPBAR         (IDM_VIEW + 7)
+    //#define    IDM_VIEW_DRAWTABBAR_INACIVETAB     (IDM_VIEW + 8) 
     #define    IDM_VIEW_POSTIT                    (IDM_VIEW + 9)
     #define    IDM_VIEW_FOLDALL                   (IDM_VIEW + 10)
     #define    IDM_VIEW_DISTRACTIONFREE           (IDM_VIEW + 11)
-    #define    IDM_VIEW_LINENUMBER                (IDM_VIEW + 12)
-    #define    IDM_VIEW_SYMBOLMARGIN              (IDM_VIEW + 13)
-    #define    IDM_VIEW_FOLDERMAGIN               (IDM_VIEW + 14)
-    #define    IDM_VIEW_FOLDERMAGIN_SIMPLE        (IDM_VIEW + 15)
-    #define    IDM_VIEW_FOLDERMAGIN_ARROW         (IDM_VIEW + 16)
-    #define    IDM_VIEW_FOLDERMAGIN_CIRCLE        (IDM_VIEW + 17)
-    #define    IDM_VIEW_FOLDERMAGIN_BOX           (IDM_VIEW + 18)
+    //#define    IDM_VIEW_LINENUMBER                (IDM_VIEW + 12)
+    //#define    IDM_VIEW_SYMBOLMARGIN              (IDM_VIEW + 13)
+    //#define    IDM_VIEW_FOLDERMAGIN               (IDM_VIEW + 14)
+    //#define    IDM_VIEW_FOLDERMAGIN_SIMPLE        (IDM_VIEW + 15)
+    //#define    IDM_VIEW_FOLDERMAGIN_ARROW         (IDM_VIEW + 16)
+    //#define    IDM_VIEW_FOLDERMAGIN_CIRCLE        (IDM_VIEW + 17)
+    //#define    IDM_VIEW_FOLDERMAGIN_BOX           (IDM_VIEW + 18)
     #define    IDM_VIEW_ALL_CHARACTERS            (IDM_VIEW + 19)
     #define    IDM_VIEW_INDENT_GUIDE              (IDM_VIEW + 20)
-    #define    IDM_VIEW_CURLINE_HILITING          (IDM_VIEW + 21)
+    //#define    IDM_VIEW_CURLINE_HILITING          (IDM_VIEW + 21)
     #define    IDM_VIEW_WRAP                      (IDM_VIEW + 22)
     #define    IDM_VIEW_ZOOMIN                    (IDM_VIEW + 23)
     #define    IDM_VIEW_ZOOMOUT                   (IDM_VIEW + 24)
     #define    IDM_VIEW_TAB_SPACE                 (IDM_VIEW + 25)
     #define    IDM_VIEW_EOL                       (IDM_VIEW + 26)
-    #define    IDM_VIEW_TOOLBAR_REDUCE_SET2       (IDM_VIEW + 27)
-    #define    IDM_VIEW_TOOLBAR_ENLARGE_SET2      (IDM_VIEW + 28)
+    //#define    IDM_VIEW_TOOLBAR_REDUCE_SET2       (IDM_VIEW + 27)
+    //#define    IDM_VIEW_TOOLBAR_ENLARGE_SET2      (IDM_VIEW + 28)
     #define    IDM_VIEW_UNFOLDALL                 (IDM_VIEW + 29)
     #define    IDM_VIEW_FOLD_CURRENT              (IDM_VIEW + 30)
     #define    IDM_VIEW_UNFOLD_CURRENT            (IDM_VIEW + 31)
@@ -310,17 +310,17 @@
     #define    IDM_VIEW_SYNSCROLLV                (IDM_VIEW + 35)
     #define    IDM_VIEW_SYNSCROLLH                (IDM_VIEW + 36)
     //#define    IDM_VIEW_EDGENONE                  (IDM_VIEW + 37)
-    #define    IDM_VIEW_DRAWTABBAR_CLOSEBOTTUN    (IDM_VIEW + 38)
-    #define    IDM_VIEW_DRAWTABBAR_DBCLK2CLOSE    (IDM_VIEW + 39)
-    #define    IDM_VIEW_REFRESHTABAR              (IDM_VIEW + 40)
+    //#define    IDM_VIEW_DRAWTABBAR_CLOSEBOTTUN    (IDM_VIEW + 38)
+    //#define    IDM_VIEW_DRAWTABBAR_DBCLK2CLOSE    (IDM_VIEW + 39)
+    //#define    IDM_VIEW_REFRESHTABAR              (IDM_VIEW + 40)
     #define    IDM_VIEW_WRAP_SYMBOL               (IDM_VIEW + 41)
     #define    IDM_VIEW_HIDELINES                 (IDM_VIEW + 42)
-    #define    IDM_VIEW_DRAWTABBAR_VERTICAL       (IDM_VIEW + 43)
-    #define    IDM_VIEW_DRAWTABBAR_MULTILINE      (IDM_VIEW + 44)
+    //#define    IDM_VIEW_DRAWTABBAR_VERTICAL       (IDM_VIEW + 43)
+    //#define    IDM_VIEW_DRAWTABBAR_MULTILINE      (IDM_VIEW + 44)
     //#define    IDM_VIEW_DOCCHANGEMARGIN           (IDM_VIEW + 45)
-    #define    IDM_VIEW_LWDEF                     (IDM_VIEW + 46)
-    #define    IDM_VIEW_LWALIGN                   (IDM_VIEW + 47)
-    #define    IDM_VIEW_LWINDENT                  (IDM_VIEW + 48)
+    //#define    IDM_VIEW_LWDEF                     (IDM_VIEW + 46)
+    //#define    IDM_VIEW_LWALIGN                   (IDM_VIEW + 47)
+    //#define    IDM_VIEW_LWINDENT                  (IDM_VIEW + 48)
     #define    IDM_VIEW_SUMMARY                   (IDM_VIEW + 49)
 
     #define    IDM_VIEW_FOLD                      (IDM_VIEW + 50)
